@@ -18,7 +18,6 @@ from multiprocessing.pool import ThreadPool
 import tqdm
 
 import rebotics_sdk
-from rebotics_sdk.advanced import remote_loaders
 
 logger = logging.getLogger(__name__)
 
@@ -329,19 +328,8 @@ class ClassificationDatabasePacker(BaseClassificationDatabasePacker):
 class DataEntry:
     label: str
     feature: typing.List[float]
-    uuid: uuid.UUID
+    uuid: typing.Optional[uuid.UUID]
     image_url: str
-    image: typing.Optional[typing.BinaryIO] = None
-
-
-def _task_unpack_classification_entry(entry: DataEntry, download_image=False):
-    if not download_image:
-        return entry
-
-    data = dataclasses.asdict(entry)
-    data['image'] = buffer = remote_loaders.download(entry.image_url)
-    buffer.seek(0)
-    return DataEntry(**data)
 
 
 class VirtualClassificationDatabasePacker(BaseClassificationDatabasePacker):
@@ -349,39 +337,40 @@ class VirtualClassificationDatabasePacker(BaseClassificationDatabasePacker):
     extension = 'rcdb'
 
     def __init__(self, *args, **kwargs):
-        self.with_images = kwargs.get('with_images', False)
         self.concurrency = kwargs.get('concurrency', None)
         if self.concurrency is None or self.concurrency < 1:
             self.concurrency = os.cpu_count()
         super(VirtualClassificationDatabasePacker, self).__init__(*args, **kwargs)
 
     def pack(self, labels, features, uuids, images, *args, **kwargs):
+        with open(labels, 'r') as labels_io:
+            self.meta_data['count'] = sum(1 for _ in labels_io)
+
         with self.zipfile(self.destination, mode='w') as zip_io:
             # writing those as a file
             zip_io.write(labels, 'labels.txt')
             zip_io.write(features, 'features.txt')
-            zip_io.write(uuids, 'uuids.txt')
+            zip_io.write(uuids, 'uuid.txt')
             zip_io.write(images, 'images.txt')
 
             zip_io.writestr('meta.json', json.dumps(self.meta_data))
         return self.destination
 
-    def unpack(self):
-        if self.with_images:
-            task = functools.partial(_task_unpack_classification_entry, download_image=True)
-        else:
-            task = _task_unpack_classification_entry
+    def unpack(self) -> typing.Iterable[DataEntry]:
+        for batch in self._data_entry_generator():
+            yield from batch
 
-        with ThreadPool(self.concurrency) as pool:
-            for batch in self._data_entry_generator():
-                yield from pool.map(task, batch)
+    def get_features_count(self):
+        with self.zipfile(self.source, mode='r') as zip_io:
+            self.meta_data = json.load(zip_io.open('meta.json'))
+        return self.meta_data.get('count')
 
     def _data_entry_generator(self):
         batch = []  # initial batch
         with self.zipfile(self.source, mode='r') as zip_io:
             labels_io = io.TextIOWrapper(zip_io.open("labels.txt"), encoding='utf-8')
             features_io = io.TextIOWrapper(zip_io.open("features.txt"), encoding='utf-8')
-            uuids_io = io.TextIOWrapper(zip_io.open("uuids.txt"), encoding='utf-8')
+            uuids_io = io.TextIOWrapper(zip_io.open("uuid.txt"), encoding='utf-8')
             images_io = io.TextIOWrapper(zip_io.open("images.txt"), encoding='utf-8')
 
             while True:
@@ -391,13 +380,18 @@ class VirtualClassificationDatabasePacker(BaseClassificationDatabasePacker):
                 image_url = images_io.readline().strip()
 
                 if label == '' or feature == '':
+                    # stop the cycle if there are empty lines
                     break
 
+                if not feature.startswith('[') and not feature.endswith(']'):
+                    feature = f'[{feature}]'
+                feature_vector = json.loads(feature)
+
                 batch.append(DataEntry(
                     label,
-                    feature,
-                    uuid_,
-                    image_url
+                    feature_vector,
+                    uuid.UUID(uuid_) if uuid_ else None,
+                    image_url if image_url else None,
                 ))
                 # if len(batch) >= self.concurrency:
                 if len(batch) >= self.concurrency:
