@@ -120,9 +120,13 @@ def process_file_response(response, destination, progress_bar=False):
         fp = open(destination, 'wb')
         is_file = True
 
+    total_length = int(response.headers.get('content-length'))
     chunk, chunk_size = 1, 1024
 
-    for chunk in tqdm(response.iter_content(chunk_size), leave=False, disable=not progress_bar):
+    for chunk in tqdm(
+        response.iter_content(chunk_size), leave=False, disable=not progress_bar,
+        unit='iB', unit_scale=True, miniters=1, unit_divisor=1024, total=total_length,
+    ):
         fp.write(chunk)
 
     if is_file:
