@@ -9,10 +9,8 @@ from time import sleep
 
 import click
 import humanize
-import tqdm
 from prettytable import PrettyTable
 
-from rebotics_sdk.advanced import remote_loaders
 from rebotics_sdk.cli.common import shell, configure, roles, set_token
 from .draw import draw_annotated_drawing
 from .renderers import format_full_table
@@ -498,6 +496,11 @@ def stitching_setup(ctx, argument, concurrency, output, draw):
         draw = False
         ctx.verbose_log("Cannot draw bboxes, no image segmentation debug file is available")
 
+    meta_df_filepath = output / "task_meta_df.csv"
+    meta_df_url = definition.get("task_meta_df", None)
+    if meta_df_url is not None:
+        files_to_load.append([meta_df_url, meta_df_filepath])
+
     for call_count, call_data in enumerate(definition['calls']):
         call_folder = output / f"call_{call_count}"
         call_folder.mkdir(parents=True, exist_ok=True)
@@ -575,7 +578,7 @@ def stitching_setup(ctx, argument, concurrency, output, draw):
             segmentation_per_image=segmentation_per_image,
             mode=mode,
             concurrency=concurrency
-       )
+        )
 
 
 api.add_command(shell, 'shell')
