@@ -312,7 +312,7 @@ def clear_ports(compose_file):
         for ports_map in value.get('ports', []):
             try:
                 published = ports_map['published']
-            except Exception as exc:
+            except Exception:
                 continue
 
             connections = [p for p in psutil.net_connections() if p.laddr.port == published]
@@ -322,5 +322,5 @@ def clear_ports(compose_file):
                 try:
                     proc = psutil.Process(con.pid)
                     proc.kill()
-                except Exception as exc:
+                except Exception:
                     pass
