@@ -814,7 +814,7 @@ def processing_action_realogram_report(ctx, concurrency, drop_duplicates, target
         df_pac['user'] = processing_action['user'].get('username', '')
         try:
             df_pac['compliance_rate'] = processing_action['compliance_rates'].get('compliance', '0')
-        except:
+        except Exception:
             df_pac['compliance_rate'] = 0
         df_pac['store_number'] = processing_action['store'].get('custom_id')
         df_scans = df_scans.append(df_pac)
